==============================
Tasks propagate Light
==============================

PropagateTargetLight
---------------------

.. autoclass:: exorad.tasks.propagateLight.PropagateTargetLight
    :members:
    :undoc-members:
    :show-inheritance:

PropagateForegroundLight
--------------------------

.. autoclass:: exorad.tasks.propagateLight.PropagateForegroundLight
    :members:
    :undoc-members:
    :show-inheritance:


